==> owncloud-8.0.8.tar.bz2: owncloud/apps/firstrunwizard/l10n/et_EE.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "Tere tulemast %s",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Sinu personaalsed veebiteenused. Kõik su failid, kontaktid, kalender ja palju muud ühes kohas.",
"Get the apps to sync your files" => "Hangi rakendusi failide sünkroniseerimiseks",
"Connect your desktop apps to %s" => "Ühenda oma töölaua rakend %s",
"Connect your Calendar" => "Ühenda oma kalender",
"Connect your Contacts" => "Ühenda oma kontaktid",
"Access files via WebDAV" => "Ligipääs WebDAV vahendusel",
"Documentation" => "Dokumentatsioon",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Rohkem infot leiad <a target=\"_blank\" href=\"%s\">dokumentatsioonist</a> ja meie <a target=\"_blank\" href=\"http://owncloud.org\">veebilehelt</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Kui Sulle meeldib ownCloud, siis\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud on suurepärane avatud lähtekoodiga tarkvara jagamaks oma faile. \n\t\tSa saad seda tasuta aadressilt http://owncloud.org\">\n\t\tsoovita seda oma sõpradelegi</a>\n\tja <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">levita sõna</a>!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-8.1.9.tar.bz2: owncloud/apps/firstrunwizard/l10n/et_EE.php <==
<?php
$TRANSLATIONS = array(
"Welcome to %s" => "Tere tulemast %s",
"Your personal web services. All your files, contacts, calendar and more, in one place." => "Sinu personaalsed veebiteenused. Kõik su failid, kontaktid, kalender ja palju muud ühes kohas.",
"Get the apps to sync your files" => "Hangi rakendusi failide sünkroniseerimiseks",
"Desktop client" => "Töölaua klient",
"Android app" => "Androidi rakendus",
"iOS app" => "iOS-i rakendus",
"Connect your desktop apps to %s" => "Ühenda oma töölaua rakendus %s",
"Connect your Calendar" => "Ühenda oma kalender",
"Connect your Contacts" => "Ühenda oma kontaktid",
"Access files via WebDAV" => "Ligipääs WebDAV vahendusel",
"Documentation" => "Dokumentatsioon",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Rohkem infot leiad <a target=\"_blank\" href=\"%s\">dokumentatsioonist</a> ja meie <a target=\"_blank\" href=\"http://owncloud.org\">veebilehelt</a>.",
"If you like ownCloud,\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud is a great open software to sync and share your files. \n\t\tYou can freely get it from http://owncloud.org\">\n\t\trecommend it to your friends</a>\n\tand <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">spread the word</a>!" => "Kui Sulle meeldib ownCloud, siis\n\t<a href=\"mailto:?subject=ownCloud\n\t\t&body=ownCloud on suurepärane avatud lähtekoodiga tarkvara jagamaks oma faile. \n\t\tSa saad seda tasuta aadressilt http://owncloud.org\">\n\t\tsoovita seda oma sõpradelegi</a>\n\tja <a href=\"http://owncloud.org/promote\"\n\t\ttarget=\"_blank\">levita sõna</a>!"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
